/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgModule } from '@angular/core';
import { ResizeBatchService } from '@progress/kendo-angular-common';
import { CalendarDOMService, CenturyViewService, DecadeViewService, MonthViewService, YearViewService, NavigationService } from '@progress/kendo-angular-dateinputs';
import { DialogContainerService, DialogService, WindowService, WindowContainerService } from '@progress/kendo-angular-dialog';
import { IconsService } from '@progress/kendo-angular-icons';
import { PopupService } from '@progress/kendo-angular-popup';
import { KENDO_GRID_BODY_EXPORTS, KENDO_GRID_COLUMN_MENU_DECLARATIONS, KENDO_GRID_DECLARATIONS, KENDO_GRID_EXPORTS, KENDO_GRID_FILTER_MENU, KENDO_GRID_FILTER_ROW, KENDO_GRID_FOOTER_EXPORTS, KENDO_GRID_GROUP_EXPORTS, KENDO_GRID_HEADER_EXPORTS, KENDO_GRID_SHARED } from './directives';
import { TableDirective } from './column-resizing/table.directive';
import { KENDO_PAGER } from '@progress/kendo-angular-pager';
import { KENDO_TOOLBAR } from '@progress/kendo-angular-toolbar';
import * as i0 from "@angular/core";
import * as i1 from "./grouping/group-header-template.directive";
import * as i2 from "./grouping/group-header-column-template.directive";
import * as i3 from "./grouping/group-footer-template.directive";
import * as i4 from "./grouping/group-header.component";
import * as i5 from "./grouping/group-panel.component";
import * as i6 from "./columns/column.component";
import * as i7 from "./columns/column-group.component";
import * as i8 from "./navigation/logical-cell.directive";
import * as i9 from "./navigation/logical-row.directive";
import * as i10 from "./navigation/focusable.directive";
import * as i11 from "./rendering/footer/footer-template.directive";
import * as i12 from "./rendering/common/col-group.component";
import * as i13 from "./layout/resizable.directive";
import * as i14 from "@progress/kendo-angular-common";
import * as i15 from "./rendering/common/field-accessor.pipe";
import * as i16 from "./rendering/details/detail-template.directive";
import * as i17 from "./columns/span-column.component";
import * as i18 from "./rendering/common/loading.component";
import * as i19 from "./rendering/grid-table.directive";
import * as i20 from "./columns/command-column.component";
import * as i21 from "./columns/checkbox-column.component";
import * as i22 from "./selection/selection-checkbox.directive";
import * as i23 from "./rendering/cell-template.directive";
import * as i24 from "./editing/edit-template.directive";
import * as i25 from "./row-reordering/drag-handle-template.directive";
import * as i26 from "./row-reordering/drag-hint-template.directive";
import * as i27 from "./rendering/table-body.component";
import * as i28 from "./rendering/no-records-template.directive";
import * as i29 from "./rendering/cell.component";
import * as i30 from "./editing/edit-command.directive";
import * as i31 from "./editing/cancel-command.directive";
import * as i32 from "./editing/save-command.directive";
import * as i33 from "./editing/remove-command.directive";
import * as i34 from "./editing/add-command.directive";
import * as i35 from "./editing/add-command-tool.directive";
import * as i36 from "./rendering/cell-loading.template.directive";
import * as i37 from "./rendering/loading-template.directive";
import * as i38 from "./columns/reorder-column.component";
import * as i39 from "./rendering/header/header.component";
import * as i40 from "./rendering/header/header-template.directive";
import * as i41 from "./column-resizing/column-handle.directive";
import * as i42 from "./selection/selectall-checkbox.directive";
import * as i43 from "./rendering/footer/footer.component";
import * as i44 from "@progress/kendo-angular-pager";
import * as i45 from "@progress/kendo-angular-toolbar";
import * as i46 from "./filtering/filter-row.component";
import * as i47 from "./filtering/cell/filter-cell.component";
import * as i48 from "./filtering/cell/filter-cell-template.directive";
import * as i49 from "./filtering/cell/string-filter-cell.component";
import * as i50 from "./filtering/cell/numeric-filter-cell.component";
import * as i51 from "./filtering/cell/autocomplete-filter-cell.component";
import * as i52 from "./filtering/cell/boolean-filter-cell.component";
import * as i53 from "./filtering/cell/filter-cell-host.directive";
import * as i54 from "./filtering/cell/filter-cell-wrapper.component";
import * as i55 from "./filtering/cell/date-filter-cell.component";
import * as i56 from "./filtering/cell/filter-cell-operators.component";
import * as i57 from "./filtering/operators/contains-filter-operator.component";
import * as i58 from "./filtering/operators/not-contains-filter-operator.component";
import * as i59 from "./filtering/operators/ends-with-filter-operator.component";
import * as i60 from "./filtering/operators/eq-filter-operator.component";
import * as i61 from "./filtering/operators/is-empty-filter-operator.component";
import * as i62 from "./filtering/operators/is-not-empty-filter-operator.component";
import * as i63 from "./filtering/operators/is-not-null-filter-operator.component";
import * as i64 from "./filtering/operators/isnull-filter-operator.component";
import * as i65 from "./filtering/operators/neq-filter-operator.component";
import * as i66 from "./filtering/operators/starts-with-filter-operator.component";
import * as i67 from "./filtering/operators/gt-filter-operator.component";
import * as i68 from "./filtering/operators/gte-filter-operator.component";
import * as i69 from "./filtering/operators/lt-filter-operator.component";
import * as i70 from "./filtering/operators/lte-filter-operator.component";
import * as i71 from "./filtering/operators/after-filter-operator.component";
import * as i72 from "./filtering/operators/after-eq-filter-operator.component";
import * as i73 from "./filtering/operators/before-eq-filter-operator.component";
import * as i74 from "./filtering/operators/before-filter-operator.component";
import * as i75 from "./filtering/filter-input.directive";
import * as i76 from "./filtering/menu/filter-menu.component";
import * as i77 from "./filtering/menu/filter-menu-container.component";
import * as i78 from "./filtering/menu/filter-menu-input-wrapper.component";
import * as i79 from "./filtering/menu/string-filter-menu-input.component";
import * as i80 from "./filtering/menu/string-filter-menu.component";
import * as i81 from "./filtering/menu/filter-menu-template.directive";
import * as i82 from "./filtering/menu/numeric-filter-menu.component";
import * as i83 from "./filtering/menu/numeric-filter-menu-input.component";
import * as i84 from "./filtering/menu/date-filter-menu-input.component";
import * as i85 from "./filtering/menu/date-filter-menu.component";
import * as i86 from "./filtering/menu/filter-menu-host.directive";
import * as i87 from "./filtering/menu/boolean-filter-menu.component";
import * as i88 from "./filtering/menu/filter-menu-dropdownlist.directive";
import * as i89 from "./filtering/menu/filter-radio-button.directive";
import * as i90 from "./column-menu/column-chooser-item-checked.directive";
import * as i91 from "./column-menu/column-list.component";
import * as i92 from "./column-menu/column-chooser.component";
import * as i93 from "./column-menu/column-chooser-tool.directive";
import * as i94 from "./column-menu/column-menu-chooser.component";
import * as i95 from "./column-menu/column-menu-filter.component";
import * as i96 from "./column-menu/column-menu-item.component";
import * as i97 from "./column-menu/column-menu-item-content-template.directive";
import * as i98 from "./column-menu/column-menu-sort.component";
import * as i99 from "./column-menu/column-menu.component";
import * as i100 from "./column-menu/column-menu-lock.component";
import * as i101 from "./column-menu/column-menu-template.directive";
import * as i102 from "./column-menu/column-menu-container.component";
import * as i103 from "./column-menu/column-menu-item.directive";
import * as i104 from "./column-menu/column-menu-stick.component";
import * as i105 from "./column-menu/column-menu-position.component";
import * as i106 from "./column-menu/column-menu-autosize.component";
import * as i107 from "./column-menu/column-menu-autosize-all.component";
import * as i108 from "./grid.component";
import * as i109 from "./rendering/list.component";
import * as i110 from "./rendering/toolbar/toolbar.component";
import * as i111 from "./localization/localized-messages.directive";
import * as i112 from "./localization/custom-messages.component";
import * as i113 from "./databinding.directive";
import * as i114 from "./rendering/toolbar/toolbar-template.directive";
import * as i115 from "./selection/selection.directive";
import * as i116 from "./editing-directives/template-editing.directive";
import * as i117 from "./editing-directives/reactive-editing.directive";
import * as i118 from "./editing-directives/in-cell-editing.directive";
import * as i119 from "./editing-directives/external-editing.directive";
import * as i120 from "./rendering/details-expand.directive";
import * as i121 from "./rendering/groups-expand.directive";
import * as i122 from "./grouping/group-scroll-binding.directive";
import * as i123 from "./selection/marquee.directive";
import * as i124 from "./rendering/common/spacer.component";
import * as i125 from "./rendering/toolbar/toolbar-focusable.directive";
import * as i126 from "./aggregates/status-bar.component";
import * as i127 from "./aggregates/status-bar-template.directive";
import * as i128 from "./common/clipboard.directive";
import * as i129 from "./editing/form/form.component";
import * as i130 from "./editing/form/dialog-form.component";
import * as i131 from "./editing/form/form-formfield.component";
// IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [NgModule](link:site.data.urls.angular['ngmoduleapi'])
 * definition for the Grid component.
 *
 * @example
 *
 * ```ts
 * import { NgModule } from '@angular/core';
 * import { GridModule } from '@progress/kendo-angular-grid';
 * import { BrowserModule } from "@angular/platform-browser";
 * import { AppComponent } from './app.component';
 *
 * @NgModule({
 *     declarations: [AppComponent],
 *     imports:      [BrowserModule, GridModule],
 *     bootstrap:    [AppComponent]
 * })
 * export class AppModule {}
 *
 * ```
 */
export class GridModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: GridModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: GridModule, imports: [i1.GroupHeaderTemplateDirective, i2.GroupHeaderColumnTemplateDirective, i3.GroupFooterTemplateDirective, i4.GroupHeaderComponent, i5.GroupPanelComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i20.CommandColumnComponent, i21.CheckboxColumnComponent, i22.SelectionCheckboxDirective, i23.CellTemplateDirective, i24.EditTemplateDirective, i25.RowDragHandleTemplateDirective, i26.RowDragHintTemplateDirective, i27.TableBodyComponent, i28.NoRecordsTemplateDirective, i29.CellComponent, i30.EditCommandDirective, i31.CancelCommandDirective, i32.SaveCommandDirective, i33.RemoveCommandDirective, i34.AddCommandDirective, i35.AddCommandToolbarDirective, i36.CellLoadingTemplateDirective, i37.LoadingTemplateDirective, i38.RowReorderColumnComponent, i39.HeaderComponent, i40.HeaderTemplateDirective, i41.ColumnHandleDirective, i42.SelectAllCheckboxDirective, i43.FooterComponent, i44.CustomMessagesComponent, i44.PagerFocusableDirective, i44.PagerInfoComponent, i44.PagerInputComponent, i44.PagerNextButtonsComponent, i44.PagerNumericButtonsComponent, i44.PagerPageSizesComponent, i44.PagerPrevButtonsComponent, i44.PagerTemplateDirective, i44.PagerComponent, i44.PagerSpacerComponent, i45.ToolBarComponent, i45.ToolbarCustomMessagesComponent, i45.ToolBarButtonComponent, i45.ToolBarButtonGroupComponent, i45.ToolBarDropDownButtonComponent, i45.ToolBarSeparatorComponent, i45.ToolBarSpacerComponent, i45.ToolBarSplitButtonComponent, i45.ToolBarToolComponent, i46.FilterRowComponent, i47.FilterCellComponent, i48.FilterCellTemplateDirective, i49.StringFilterCellComponent, i50.NumericFilterCellComponent, i51.AutoCompleteFilterCellComponent, i52.BooleanFilterCellComponent, i53.FilterCellHostDirective, i54.FilterCellWrapperComponent, i55.DateFilterCellComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i56.FilterCellOperatorsComponent, i57.ContainsFilterOperatorComponent, i58.DoesNotContainFilterOperatorComponent, i59.EndsWithFilterOperatorComponent, i60.EqualFilterOperatorComponent, i61.IsEmptyFilterOperatorComponent, i62.IsNotEmptyFilterOperatorComponent, i63.IsNotNullFilterOperatorComponent, i64.IsNullFilterOperatorComponent, i65.NotEqualFilterOperatorComponent, i66.StartsWithFilterOperatorComponent, i67.GreaterFilterOperatorComponent, i68.GreaterOrEqualToFilterOperatorComponent, i69.LessFilterOperatorComponent, i70.LessOrEqualToFilterOperatorComponent, i71.AfterFilterOperatorComponent, i72.AfterEqFilterOperatorComponent, i73.BeforeEqFilterOperatorComponent, i74.BeforeFilterOperatorComponent, i75.FilterInputDirective, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i56.FilterCellOperatorsComponent, i57.ContainsFilterOperatorComponent, i58.DoesNotContainFilterOperatorComponent, i59.EndsWithFilterOperatorComponent, i60.EqualFilterOperatorComponent, i61.IsEmptyFilterOperatorComponent, i62.IsNotEmptyFilterOperatorComponent, i63.IsNotNullFilterOperatorComponent, i64.IsNullFilterOperatorComponent, i65.NotEqualFilterOperatorComponent, i66.StartsWithFilterOperatorComponent, i67.GreaterFilterOperatorComponent, i68.GreaterOrEqualToFilterOperatorComponent, i69.LessFilterOperatorComponent, i70.LessOrEqualToFilterOperatorComponent, i71.AfterFilterOperatorComponent, i72.AfterEqFilterOperatorComponent, i73.BeforeEqFilterOperatorComponent, i74.BeforeFilterOperatorComponent, i75.FilterInputDirective, i76.FilterMenuComponent, i77.FilterMenuContainerComponent, i78.FilterMenuInputWrapperComponent, i79.StringFilterMenuInputComponent, i80.StringFilterMenuComponent, i81.FilterMenuTemplateDirective, i82.NumericFilterMenuComponent, i83.NumericFilterMenuInputComponent, i84.DateFilterMenuInputComponent, i85.DateFilterMenuComponent, i86.FilterMenuHostDirective, i87.BooleanFilterMenuComponent, i88.FilterMenuDropDownListDirective, i89.BooleanFilterRadioButtonDirective, i90.ColumnMenuChooserItemCheckedDirective, i91.ColumnListComponent, i92.ColumnChooserComponent, i93.ColumnChooserToolbarDirective, i94.ColumnMenuChooserComponent, i95.ColumnMenuFilterComponent, i96.ColumnMenuItemComponent, i97.ColumnMenuItemContentTemplateDirective, i98.ColumnMenuSortComponent, i99.ColumnMenuComponent, i100.ColumnMenuLockComponent, i101.ColumnMenuTemplateDirective, i102.ColumnMenuContainerComponent, i103.ColumnMenuItemDirective, i104.ColumnMenuStickComponent, i105.ColumnMenuPositionComponent, i106.ColumnMenuAutoSizeColumnComponent, i107.ColumnMenuAutoSizeAllColumnsComponent, i108.GridComponent, i109.ListComponent, i110.ToolbarComponent, i111.LocalizedMessagesDirective, i112.CustomMessagesComponent, i113.DataBindingDirective, i114.ToolbarTemplateDirective, i115.SelectionDirective, i116.TemplateEditingDirective, i117.ReactiveEditingDirective, i118.InCellEditingDirective, i119.ExternalEditingDirective, i120.ExpandDetailsDirective, i121.ExpandGroupDirective, i122.GroupBindingDirective, i123.GridMarqueeDirective, i124.GridSpacerComponent, i125.GridToolbarFocusableDirective, i126.StatusBarComponent, i127.StatusBarTemplateDirective, i128.GridClipboardDirective, i129.FormComponent, i130.DialogFormComponent, i131.FormFormFieldComponent, i45.ToolBarComponent, i45.ToolbarCustomMessagesComponent, i45.ToolBarButtonComponent, i45.ToolBarButtonGroupComponent, i45.ToolBarDropDownButtonComponent, i45.ToolBarSeparatorComponent, i45.ToolBarSpacerComponent, i45.ToolBarSplitButtonComponent, i45.ToolBarToolComponent, TableDirective], exports: [i108.GridComponent, i114.ToolbarTemplateDirective, i110.ToolbarComponent, i124.GridSpacerComponent, i127.StatusBarTemplateDirective, i113.DataBindingDirective, i115.SelectionDirective, i112.CustomMessagesComponent, i122.GroupBindingDirective, i116.TemplateEditingDirective, i117.ReactiveEditingDirective, i118.InCellEditingDirective, i119.ExternalEditingDirective, i120.ExpandDetailsDirective, i121.ExpandGroupDirective, i125.GridToolbarFocusableDirective, i1.GroupHeaderTemplateDirective, i2.GroupHeaderColumnTemplateDirective, i3.GroupFooterTemplateDirective, i4.GroupHeaderComponent, i5.GroupPanelComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i20.CommandColumnComponent, i21.CheckboxColumnComponent, i22.SelectionCheckboxDirective, i23.CellTemplateDirective, i24.EditTemplateDirective, i25.RowDragHandleTemplateDirective, i26.RowDragHintTemplateDirective, i27.TableBodyComponent, i28.NoRecordsTemplateDirective, i29.CellComponent, i30.EditCommandDirective, i31.CancelCommandDirective, i32.SaveCommandDirective, i33.RemoveCommandDirective, i34.AddCommandDirective, i35.AddCommandToolbarDirective, i36.CellLoadingTemplateDirective, i37.LoadingTemplateDirective, i38.RowReorderColumnComponent, i39.HeaderComponent, i40.HeaderTemplateDirective, i41.ColumnHandleDirective, i42.SelectAllCheckboxDirective, i46.FilterRowComponent, i47.FilterCellComponent, i48.FilterCellTemplateDirective, i49.StringFilterCellComponent, i50.NumericFilterCellComponent, i51.AutoCompleteFilterCellComponent, i52.BooleanFilterCellComponent, i53.FilterCellHostDirective, i54.FilterCellWrapperComponent, i55.DateFilterCellComponent, i56.FilterCellOperatorsComponent, i57.ContainsFilterOperatorComponent, i58.DoesNotContainFilterOperatorComponent, i59.EndsWithFilterOperatorComponent, i60.EqualFilterOperatorComponent, i61.IsEmptyFilterOperatorComponent, i62.IsNotEmptyFilterOperatorComponent, i63.IsNotNullFilterOperatorComponent, i64.IsNullFilterOperatorComponent, i65.NotEqualFilterOperatorComponent, i66.StartsWithFilterOperatorComponent, i67.GreaterFilterOperatorComponent, i68.GreaterOrEqualToFilterOperatorComponent, i69.LessFilterOperatorComponent, i70.LessOrEqualToFilterOperatorComponent, i71.AfterFilterOperatorComponent, i72.AfterEqFilterOperatorComponent, i73.BeforeEqFilterOperatorComponent, i74.BeforeFilterOperatorComponent, i76.FilterMenuComponent, i77.FilterMenuContainerComponent, i78.FilterMenuInputWrapperComponent, i79.StringFilterMenuInputComponent, i80.StringFilterMenuComponent, i81.FilterMenuTemplateDirective, i82.NumericFilterMenuComponent, i83.NumericFilterMenuInputComponent, i84.DateFilterMenuInputComponent, i85.DateFilterMenuComponent, i86.FilterMenuHostDirective, i87.BooleanFilterMenuComponent, i88.FilterMenuDropDownListDirective, i89.BooleanFilterRadioButtonDirective, i92.ColumnChooserComponent, i93.ColumnChooserToolbarDirective, i95.ColumnMenuFilterComponent, i96.ColumnMenuItemComponent, i97.ColumnMenuItemContentTemplateDirective, i98.ColumnMenuSortComponent, i100.ColumnMenuLockComponent, i104.ColumnMenuStickComponent, i105.ColumnMenuPositionComponent, i94.ColumnMenuChooserComponent, i101.ColumnMenuTemplateDirective, i102.ColumnMenuContainerComponent, i103.ColumnMenuItemDirective, i99.ColumnMenuComponent, i106.ColumnMenuAutoSizeColumnComponent, i107.ColumnMenuAutoSizeAllColumnsComponent, i128.GridClipboardDirective, i45.ToolBarComponent, i45.ToolbarCustomMessagesComponent, i45.ToolBarButtonComponent, i45.ToolBarButtonGroupComponent, i45.ToolBarDropDownButtonComponent, i45.ToolBarSeparatorComponent, i45.ToolBarSpacerComponent, i45.ToolBarSplitButtonComponent, i45.ToolBarToolComponent, i44.CustomMessagesComponent, i44.PagerFocusableDirective, i44.PagerInfoComponent, i44.PagerInputComponent, i44.PagerNextButtonsComponent, i44.PagerNumericButtonsComponent, i44.PagerPageSizesComponent, i44.PagerPrevButtonsComponent, i44.PagerTemplateDirective, i44.PagerComponent, i44.PagerSpacerComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: GridModule, providers: [
            PopupService,
            ResizeBatchService,
            IconsService,
            DialogContainerService,
            DialogService,
            WindowService,
            WindowContainerService,
            CalendarDOMService,
            CenturyViewService,
            DecadeViewService,
            MonthViewService,
            YearViewService,
            NavigationService
        ], imports: [i4.GroupHeaderComponent, i5.GroupPanelComponent, i27.TableBodyComponent, i29.CellComponent, i30.EditCommandDirective, i31.CancelCommandDirective, i32.SaveCommandDirective, i33.RemoveCommandDirective, i34.AddCommandDirective, i39.HeaderComponent, i44.CustomMessagesComponent, i44.PagerInfoComponent, i44.PagerInputComponent, i44.PagerNextButtonsComponent, i44.PagerNumericButtonsComponent, i44.PagerPageSizesComponent, i44.PagerPrevButtonsComponent, i44.PagerComponent, i44.PagerSpacerComponent, i45.ToolBarComponent, i45.ToolbarCustomMessagesComponent, i45.ToolBarButtonComponent, i45.ToolBarButtonGroupComponent, i45.ToolBarDropDownButtonComponent, i45.ToolBarSeparatorComponent, i45.ToolBarSpacerComponent, i45.ToolBarSplitButtonComponent, i49.StringFilterCellComponent, i50.NumericFilterCellComponent, i51.AutoCompleteFilterCellComponent, i52.BooleanFilterCellComponent, i54.FilterCellWrapperComponent, i55.DateFilterCellComponent, i56.FilterCellOperatorsComponent, i56.FilterCellOperatorsComponent, i76.FilterMenuComponent, i77.FilterMenuContainerComponent, i78.FilterMenuInputWrapperComponent, i79.StringFilterMenuInputComponent, i80.StringFilterMenuComponent, i82.NumericFilterMenuComponent, i83.NumericFilterMenuInputComponent, i84.DateFilterMenuInputComponent, i85.DateFilterMenuComponent, i87.BooleanFilterMenuComponent, i91.ColumnListComponent, i92.ColumnChooserComponent, i94.ColumnMenuChooserComponent, i95.ColumnMenuFilterComponent, i96.ColumnMenuItemComponent, i98.ColumnMenuSortComponent, i99.ColumnMenuComponent, i100.ColumnMenuLockComponent, i104.ColumnMenuStickComponent, i105.ColumnMenuPositionComponent, i106.ColumnMenuAutoSizeColumnComponent, i107.ColumnMenuAutoSizeAllColumnsComponent, i108.GridComponent, i109.ListComponent, i129.FormComponent, i130.DialogFormComponent, i131.FormFormFieldComponent, i45.ToolBarComponent, i45.ToolbarCustomMessagesComponent, i45.ToolBarButtonComponent, i45.ToolBarButtonGroupComponent, i45.ToolBarDropDownButtonComponent, i45.ToolBarSeparatorComponent, i45.ToolBarSpacerComponent, i45.ToolBarSplitButtonComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: GridModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_GRID_EXPORTS, ...KENDO_TOOLBAR, ...KENDO_PAGER],
                    imports: [
                        ...KENDO_GRID_GROUP_EXPORTS,
                        ...KENDO_GRID_SHARED,
                        ...KENDO_GRID_BODY_EXPORTS,
                        ...KENDO_GRID_HEADER_EXPORTS,
                        ...KENDO_GRID_FOOTER_EXPORTS,
                        ...KENDO_PAGER,
                        ...KENDO_TOOLBAR,
                        ...KENDO_GRID_FILTER_ROW,
                        ...KENDO_GRID_FILTER_MENU,
                        ...KENDO_GRID_COLUMN_MENU_DECLARATIONS,
                        ...KENDO_GRID_DECLARATIONS,
                        ...KENDO_TOOLBAR,
                        TableDirective
                    ],
                    providers: [
                        PopupService,
                        ResizeBatchService,
                        IconsService,
                        DialogContainerService,
                        DialogService,
                        WindowService,
                        WindowContainerService,
                        CalendarDOMService,
                        CenturyViewService,
                        DecadeViewService,
                        MonthViewService,
                        YearViewService,
                        NavigationService
                    ]
                }]
        }] });
